#ifdef GL_ES
precision lowp float;
#endif

varying vec2 v_position;
varying vec2 v_texCoord;
varying float v_texUnit;

uniform sampler2D CC_Texture00;
uniform sampler2D CC_Texture01;
uniform sampler2D CC_Texture02;
uniform sampler2D CC_Texture03;
uniform sampler2D CC_Texture04;
uniform sampler2D CC_Texture05;
uniform sampler2D CC_Texture06;
uniform sampler2D CC_Texture07;

#define CloudUnit0 CC_Texture00

uniform vec3 CC_Tint;

vec4 getCloudPixel()
{
    vec2 position = vec2(v_position.x + CC_Time.r, v_position.y + CC_Time.r);
    vec4 cloud1 = texture2D(CloudUnit0, position);
    vec2 flippedPosition = vec2(CC_Time.g - v_position.x, CC_Time.g - v_position.y);
    vec4 cloud2 = vec4(texture2D(CloudUnit0, flippedPosition).rgb, 0.8);

    float ratio = (CC_SinTime.a + 1.0) / 2.0;
    float antiRatio = (1.0 - ratio);

    vec4 mixedPixel = (cloud1 * ratio) + (cloud2 * antiRatio);
    vec4 c = mixedPixel;
    
    return c;
}

vec3 getPureCloudPixel()
{
    vec4 cloudPixel = getCloudPixel();
    vec3 cloudComponent = cloudPixel.rgb * cloudPixel.a;
    vec3 landComponent = vec3(0.87, 0.93, 0.92) * (1.0 - cloudPixel.a);
    vec3 combined = cloudComponent + landComponent;
    
    return combined;
}

vec4 getTexUnitPixel()
{
    if (v_texUnit < .003)
        return texture2D(CC_Texture00, v_texCoord);
    else if (v_texUnit < .007)
        return texture2D(CC_Texture01, v_texCoord);
    else if (v_texUnit < .011)
        return texture2D(CC_Texture02, v_texCoord);
    else if (v_texUnit < .015)
        return texture2D(CC_Texture03, v_texCoord);
    else if (v_texUnit < .019)
        return texture2D(CC_Texture04, v_texCoord);
    else if (v_texUnit < .023)
        return texture2D(CC_Texture05, v_texCoord);
    else if (v_texUnit < .027)
        return texture2D(CC_Texture06, v_texCoord);
    else // if (v_texUnit < .031)
        return texture2D(CC_Texture07, v_texCoord);
}

vec4 getBorderCloudPixel()
{
    vec4 borderPixel = getTexUnitPixel();
    vec3 borderComponent = borderPixel.rgb * borderPixel.a;

    vec3 cloudPixel = getPureCloudPixel();
    vec3 cloudComponent = cloudPixel * (1.0 - borderPixel.a);

    vec3 combined = borderComponent + cloudComponent;
    
    return vec4(combined, 1.0);
}

void main()
{
    vec4 pixel = getBorderCloudPixel();
    pixel.rgb = (CC_Tint * pixel.rgb) * pixel.a;
    gl_FragColor = pixel;
}